# Copyright 2014 NYBX Inc
# See LICENSE file for details.

"""
:module: ledgerx.settings
:synopsis: A module that lets clients specify settings.
"""

import os
import logging
import multiprocessing

from ledgerx.store import MessageIDStore
from ledgerx.utils import logger

# Core configurations

THREAD_COUNT = multiprocessing.cpu_count()
SOCKET_LINGER = 1000 # ms
ID_STORE = MessageIDStore()
LEDGERX_TEST = os.getenv('LEDGERX_TEST', False) != ''
LEDGERX_STAGING = os.getenv('LEDGERX_STAGING', False) != ''
DEBUG = os.getenv('DEBUG', False) != ''

if DEBUG:
    logger.addHandler(logging.StreamHandler())

# Endpoints

def __endpoint(scheme, port):
    import socket

    fqdn = 'api.ledgerx.com'

    if LEDGERX_STAGING:
        fqdn = 'test.ledgerx.com'

    if LEDGERX_TEST:
        fqdn = '127.0.0.1'

    try:
        host = socket.gethostbyname(fqdn)
    except socket.gaierror:
        host = '127.0.0.1'
        logger.critical(
                "error resolving {}, defaulting to localhost".format(fqdn))
    return "{0}://{1}:{2}".format(scheme, host, port)

EXCHANGE_ENDPOINT = __endpoint('tcp', 54494)
EXCHANGE_PUBLISHER_ENDPOINT = __endpoint('tcp', 54495)

